@@ -3,7 +3,6 @@
 extern crate self as cppvtbl;
 
 use core::{
-	ffi::c_void,
 	marker::PhantomPinned,
 	mem,
 	ops::{Deref, DerefMut},
@@ -67,20 +66,20 @@ impl<V: 'static> VtableRef<V> {
 	pub fn table(&self) -> &'static V {
 		self.0
 	}
-	pub fn into_raw(v: &Self) -> *const c_void {
-		v as *const _ as *const c_void
+	pub fn into_raw(v: &Self) -> *const VtableRef<V> {
+		v as *const _
 	}
-	pub fn into_raw_mut(v: Pin<&mut Self>) -> *mut c_void {
+	pub fn into_raw_mut(v: Pin<&mut Self>) -> *mut VtableRef<V> {
 		// Safety: we returning pinned value as raw pointer,
 		// it is impossible to move data without using unsafe
-		unsafe { Pin::get_unchecked_mut(v) as *mut _ as *mut c_void }
+		unsafe { Pin::get_unchecked_mut(v) as *mut _ }
 	}
 	/// Safety: lifetime should be correctly specified
-	pub unsafe fn from_raw<'r>(raw: *const c_void) -> &'r Self {
+	pub unsafe fn from_raw<'r>(raw: *const VtableRef<V>) -> &'r Self {
 		mem::transmute(raw as *const _ as *const Self)
 	}
 	/// Safety: lifetime should be correctly specified
-	pub unsafe fn from_raw_mut<'r>(raw: *mut c_void) -> Pin<&'r mut Self> {
+	pub unsafe fn from_raw_mut<'r>(raw: *mut VtableRef<V>) -> Pin<&'r mut Self> {
 		mem::transmute(raw as *mut _ as *mut Self)
 	}
 }
